summaryrefslogtreecommitdiffstats
path: root/source/Mobs/Magmacube.h
diff options
context:
space:
mode:
authorTiger Wang <ziwei.tiger@hotmail.co.uk>2013-09-18 23:17:43 +0200
committerTiger Wang <ziwei.tiger@hotmail.co.uk>2013-09-18 23:17:43 +0200
commit3e698d7b72ad7f58a1a2ab787f49c82e096845f6 (patch)
treecb7ae4dec5750c6e0c5116c80493d2b9e5a4eb52 /source/Mobs/Magmacube.h
parentImplemented redstone comparators (diff)
downloadcuberite-3e698d7b72ad7f58a1a2ab787f49c82e096845f6.tar
cuberite-3e698d7b72ad7f58a1a2ab787f49c82e096845f6.tar.gz
cuberite-3e698d7b72ad7f58a1a2ab787f49c82e096845f6.tar.bz2
cuberite-3e698d7b72ad7f58a1a2ab787f49c82e096845f6.tar.lz
cuberite-3e698d7b72ad7f58a1a2ab787f49c82e096845f6.tar.xz
cuberite-3e698d7b72ad7f58a1a2ab787f49c82e096845f6.tar.zst
cuberite-3e698d7b72ad7f58a1a2ab787f49c82e096845f6.zip
Diffstat (limited to '')
-rw-r--r--source/Mobs/Magmacube.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/Mobs/Magmacube.h b/source/Mobs/Magmacube.h
index e4df4f33d..80a1d0701 100644
--- a/source/Mobs/Magmacube.h
+++ b/source/Mobs/Magmacube.h
@@ -7,22 +7,22 @@
-class cMagmacube :
+class cMagmaCube :
public cAggressiveMonster
{
typedef cAggressiveMonster super;
public:
- /// Creates a magmacube of the specified size; size is 1 .. 3, with 1 being the smallest
- cMagmacube(int a_Size);
+ /// Creates a MagmaCube of the specified size; size is 1 .. 3, with 1 being the smallest
+ cMagmaCube(int a_Size);
- CLASS_PROTODEF(cMagmacube);
+ CLASS_PROTODEF(cMagmaCube);
virtual void GetDrops(cItems & a_Drops, cEntity * a_Killer = NULL) override;
protected:
/// Size of the magmacube, 1 .. 3, with 1 being the smallest
int m_Size;
} ;
@@ -7,22 +7,22 @@
virtual void GetDrops(cItems & a_Drops, cEntity * a_Killer = NULL) override;
protected:
- /// Size of the magmacube, 1 .. 3, with 1 being the smallest
+ /// Size of the MagmaCube, 1 .. 3, with 1 being the smallest
int m_Size;
} ;